@@ -1,12 +1,25 @@
 test_that("scout action works", {
   action <- scout_action("id", "label", "descr")
   expect_type(action, "list")
-  expect(length(action), 2)
+  expect_length(action, 2)
   expect_true(all(names(action) %in% c("children", "class")))
   expect_identical(action$class, "scout_action")
 
   expect_type(action$children, "list")
   expect_identical(action$children$ariaLabel, "id")
+
+  # Pass icons as shiny tags
+  expect_snapshot(
+    error = TRUE,
+    {
+      scout_action(
+        id = 3,
+        icon = "house",
+        label = "3",
+        description = "3"
+      )
+    }
+  )
 })
 
 test_that("scout section works", {
@@ -19,7 +32,7 @@ test_that("scout section works", {
   )
 
   expect_type(section, "list")
-  expect(length(section), 3)
+  expect_length(section, 3)
   expect_true(all(names(section) %in% c("children", "label", "class")))
   expect_identical(section$class, "scout_section")
 
@@ -37,7 +50,7 @@ test_that("scout page works", {
   )
 
   expect_type(page, "list")
-  expect(length(page), 3)
+  expect_length(page, 3)
   expect_true(all(names(page) %in% c("children", "label", "class")))
   expect_identical(page$class, "scout_page")
 
@@ -77,7 +90,9 @@ test_that("update scoutbar works", {
 
 # shinytest2
 library(shinytest2)
+
 test_that("App initialization is consistent", {
+  skip_on_cran()
   app <- AppDriver$new(
     system.file("examples/simple", package = "scoutbaR"),
     name = "simple"
@@ -85,12 +100,21 @@ test_that("App initialization is consistent", {
 
   app$expect_values()
 
-  app$click("update")
+  app$click("open")
   app$wait_for_idle()
   app$expect_values()
 
   app$click(selector = ".scoutbar-cell-item[aria-label=\"1\"]")
   app$wait_for_idle()
   app$expect_values()
+
+  app$click("update")
+  app$wait_for_idle()
+  app$expect_values()
+
+  app$click("open")
+  app$wait_for_idle()
+  app$expect_values()
+
   app$stop()
 })
